[![CI](https://github.com/epics-containers/ibek/actions/workflows/ci.yml/badge.svg)](https://github.com/epics-containers/ibek/actions/workflows/ci.yml)
[![Coverage](https://codecov.io/gh/epics-containers/ibek/branch/main/graph/badge.svg)](https://codecov.io/gh/epics-containers/ibek)
[![PyPI](https://img.shields.io/pypi/v/ibek.svg)](https://pypi.org/project/ibek)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://www.apache.org/licenses/LICENSE-2.0)

# ibek

IOC builder for EPICS and Kubernetes


Source          | <https://github.com/epics-containers/ibek>
:---:           | :---:
PyPI            | `pip install ibek`
Documentation   | <https://epics-containers.github.io/ibek>
Releases        | <https://github.com/epics-containers/ibek/releases>


<!-- README only content. Anything below this line won't be included in index.md -->

See https://epics-containers.github.io/ibek for more detailed documentation.
